define(
//begin v1.x content
({
	insertTableTitle: "Infoga tabell",
	modifyTableTitle: "Ändra tabell",
	rows: "Rader:",
	columns: "Kolumner:",
	align: "Justera:",
	cellPadding: "Cellutfyllnad:",
	cellSpacing: "Cellavstånd:",
	tableWidth: "Tabellbredd:",
	backgroundColor: "Bakgrundsfärg:",
	borderColor: "Ramfärg:",
	borderThickness: "Ramtjocklek",
	percent: "%",
	pixels: "bildpunkter",
	"default": "standard",
	left: "vänsterjustera",
	center: "centrera",
	right: "högerjustera",
	buttonSet: "Ange", // translated elsewhere?
	buttonInsert: "Infoga",
	buttonCancel: "Avbryt",

	selectTableLabel: "Välj tabell",
	insertTableRowBeforeLabel: "Lägg till rad före",
	insertTableRowAfterLabel: "Lägg till rad efter",
	insertTableColumnBeforeLabel: "Lägg till kolumn före",
	insertTableColumnAfterLabel: "Lägg till kolumn efter",
	deleteTableRowLabel: "Ta bort rad",
	deleteTableColumnLabel: "Ta bort kolumn"
})
//end v1.x content
);
